@@ -4,13 +4,14 @@
 """
 
 from __future__ import print_function, unicode_literals
+
 import os
-import sys
 import subprocess
+import sys
+
 from zerobug import Z0BUG
 
-
-__version__ = "1.0.9"
+__version__ = "1.0.10"
 STS_FAILED = 1
 STS_SUCCESS = 0
 
@@ -23,10 +24,13 @@ if __name__ == "__main__":
         sys.exit(STS_SUCCESS)
     test_file = 'test_%s.py' % Z0BUG.module_id
     # gen_test_file = 'all_tests.py'
-    if (action == '-T' or ('DEV_ENVIRONMENT' in os.environ and
-                           os.environ['DEV_ENVIRONMENT'] == Z0BUG.module_id)):
-        if (os.path.isdir('./tests') and
-                os.path.isfile(os.path.join('tests', test_file))):
+    if action == '-T' or (
+        'DEV_ENVIRONMENT' in os.environ
+        and os.environ['DEV_ENVIRONMENT'] == Z0BUG.module_id
+    ):
+        if os.path.isdir('./tests') and os.path.isfile(
+            os.path.join('tests', test_file)
+        ):
             os.chdir('./tests')
             sts = subprocess.call(test_file)
         elif os.path.isfile(test_file):
